// =======================================================================
//  This software is the property of Precise Automation and can be freely
//  copied and used by Precise's customers so long as this notice is
//  included with any modified or unmodified version of this software.
// =======================================================================

/* Set of functions used to communicate to GPL program for sending
   command requests, waiting for command to complete and then
   returning response */

// Cmd is made up of a command string and up to 4 argument strings.
// The communication to GPL is done using DataID 1800 to 1804 which are allocated
// for GPL program use.
// 1800 - Cmd string
// 1801 - Arg1
// 1802 - Arg2
// 1803 - Arg3
// 1804 - Arg4
//
// Once a command is executed, the response is monitored by looking at a STT dataID 
// allocated for use in GPL.
// 
// 1850 - Cmd STT (numeric)
//		  0 -- idle
//		  1 -- busy
//		 -n -- error where n is the error code.
// 1819 - Cmd STT (string)
//        response string if any including the error string if applicable.


var xmlHttp
var CmdOut = ""
var LastCmd = ""
var Stt = 0
var SttStr = "success"
var busy = 0
var count = 0
var cmdBusy = 0
var cmdReqErr = 0

function sndCmd(cmd, arg1, arg2, arg3, arg4) {
	
	if(cmdBusy==0){
		cmdReqErr = 0		//reset any request error flags
		cmdBusy = 1;		// indicating last command busy
		var db=window.frames["cmdPut"] 	//get reference to db driver
		CmdOut = cmd		//assigned and polled.  Determines when command is accepted by GPL program.
		LastCmd = cmd		//used for echo back
		db.dbPutCmd(cmd,arg1,arg2,arg3,arg4)
		logInfo("Cmd: "+cmd+" "+arg1+" "+arg2);
		
		// need to check the status of the command
		waitCmdAccept()
	}
	else{
		// flag that the request has failed so calling routine can handle error
		cmdReqErr = 1
		alert("Last Command Still Busy...");
	}
}
// for debugging.  requires main page to have a object to push values into.
function logInfo(data){
	//var fld = document.getElementById("txtStatus")
	//fld.value += data + "\n";
}

function waitCmdAccept(){
	if (CmdOut.length>0){	//make sure cmd accepted
		if(busy==0){
			busy=1
			SttStr = ""
			updateStt();
		}
		var times = setTimeout("waitCmdAccept()",50);
		logInfo("WaitAccept ")
}
	else{
		Stt=1		//force busy state
		SttStr = ""
		waitCmdComplete();
	}
}
function waitCmdComplete(){
	logInfo("WaitComplete ");
		
	if (Stt==1){	// wait for not busy
		if(busy==0){
			busy=1
			updateStt();
		}
		var times = setTimeout("waitCmdComplete()",50);
		logInfo("WaitComplete BUSY");
	}
	else{
		// it is required that any page that includes this script must provide
		// a method for handling this call.
		logInfo("Reply " + LastCmd + " " + Stt + " " + SttStr)
		cmdBusy=0;		//allow new command
		cmdReply(LastCmd,Stt,SttStr);
	}
}


function updateStt(){
		xmlHttp=new ActiveXObject("Microsoft.XMLHTTP")
		var url="/flash/appweb/shared/cmdrply.asp";
		xmlHttp.onreadystatechange=stateChanged
		xmlHttp.open("GET",url,true)
		// fixes cache issue
		xmlHttp.setRequestHeader( "If-Modified-Since", "Sat, 1 Jan 2000 00:00:00 GMT" );
		xmlHttp.send(null)
		logInfo("HttpGet " + url)
		count += 1;

}

function stateChanged(){
	if (xmlHttp.readyState==4 || xmlHttp.readyState=="complete"){
		
		xmlHttp.onreadystatechange = new function(){}		//fixes memory leak
		
		iArray = xmlHttp.responseText.split(",");
					//alert(iArray.length);
					//for(i=0;i<iArray.length;i++){
					//	ctable.rows[i+1].cells[1].innerHTML = iArray[i]
					//}
			
		CmdOut = iArray[0]	// current command sent
		SttStr = iArray[2]	// string response
		Stt = parseInt(iArray[1])		// numeric error code 0 = success
		logInfo("Done "+ xmlHttp.statusText)
		busy=0				// reset flag for polling
	}
}


